// ==============================================================
//                 ORBITER MODULE: Atlantis
//                  Part of the ORBITER SDK
//          Copyright (C) 2001-2004 Martin Schweiger
//                   All rights reserved
//
// HST.h
// HST basic specs and animations
//
// HST mesh and textures by David Sundstrom
// ==============================================================

#ifndef __HST_H
#define __HST_H

#define STRICT
#include "orbitersdk.h"

// ==============================================================
// Some parameters and capabilities
// ==============================================================

const double HST_SIZE = 7.52;
const double HST_EMPTY_MASS = 20000;
const double ANTENNA_OPERATING_SPEED = 0.025;
const double HATCH_OPERATING_SPEED = 0.022;
const double ARRAY_OPERATING_SPEED = 0.02;

// ==============================================================
// HST class interface
// ==============================================================

class HST: public VESSEL2 {
public:
	enum DoorStatus { DOOR_CLOSED, DOOR_OPEN, DOOR_CLOSING, DOOR_OPENING } ant_status, hatch_status, fold_status;
	HST (OBJHANDLE hObj, int fmodel);
	void DefineAnimations (void);
	void RevertAntenna (void);
	void RevertHatch (void);
	void RevertArray (void);

	// Overloaded callback functions
	void clbkSetClassCaps (FILEHANDLE cfg);
	void clbkLoadStateEx (FILEHANDLE scn, void *vs);
	void clbkSaveState (FILEHANDLE scn);
	void clbkPostStep (double simt, double simdt, double mjd);
	int  clbkConsumeBufferedKey (DWORD key, bool down, char *kstate);

private:
	UINT anim_ant, anim_hatch, anim_fold;
	double ant_proc, hatch_proc, fold_proc;
};

#endif // !__HST_H